@@ -5,9 +5,16 @@ Copyright (C) 2021 Aaqa Ishtyaq
 use iay::colors;
 use std::env;
 
-pub fn prompt_char() -> String {
-    let user_char = env::var("IAY_PROMPT_CHAR").unwrap_or_else(|_| "% ".into());
-    let root_char = env::var("IAY_PROMPT_CHAR_ROOT").unwrap_or_else(|_| "# ".into());
+pub fn prompt_char(zsh: bool) -> String {
+    let shell_user_char = if zsh {
+        // % is a special char in zsh, escape it.
+        "%#"
+    } else {
+        "$"
+    };
+
+    let user_char = env::var("IAY_PROMPT_CHAR").unwrap_or_else(|_| shell_user_char.into());
+    let root_char = env::var("IAY_PROMPT_CHAR_ROOT").unwrap_or_else(|_| "#".into());
     let user_char_color = env::var("IAY_PROMPT_CHAR_COLOR").unwrap_or_else(|_| "blue".into());
     let root_char_color = env::var("IAY_PROMPT_CHAR_ROOT_COLOR").unwrap_or_else(|_| "red".into());
 
